==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/LiteralIntegerSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.LiteralInteger;
import io.ciera.tool.sql.ooaofooa.value.LiteralIntegerSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class LiteralIntegerSetImpl extends InstanceSet<LiteralIntegerSet,LiteralInteger> implements LiteralIntegerSet {

    // attributes
    @Override
    public void setValue( String m_Value ) throws XtumlException {
        for ( LiteralInteger literalinteger : this ) literalinteger.setValue( m_Value );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( LiteralInteger literalinteger : this ) literalinteger.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( LiteralInteger literalinteger : this ) valueset.add( literalinteger.R801_is_a_Value() );
        return valueset;
    }


    @Override
    public LiteralInteger nullElement() {
        return LiteralIntegerImpl.EMPTY_LITERALINTEGER;
    }

    @Override
    public LiteralIntegerSet emptySet() {
      return new LiteralIntegerSetImpl();
    }

    @Override
    public LiteralIntegerSet value() {
        return this;
    }

    @Override
    public List<LiteralInteger> elements() {
        return Arrays.asList(toArray(new LiteralInteger[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/LiteralIntegerSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.LiteralInteger;
import io.ciera.tool.sql.ooaofooa.value.LiteralIntegerSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class LiteralIntegerSetImpl extends InstanceSet<LiteralIntegerSet,LiteralInteger> implements LiteralIntegerSet {

    public LiteralIntegerSetImpl() {
    }

    public LiteralIntegerSetImpl(Comparator<? super LiteralInteger> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( LiteralInteger literalinteger : this ) literalinteger.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setValue( String m_Value ) throws XtumlException {
        for ( LiteralInteger literalinteger : this ) literalinteger.setValue( m_Value );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( LiteralInteger literalinteger : this ) valueset.add( literalinteger.R801_is_a_Value() );
        return valueset;
    }


    @Override
    public LiteralInteger nullElement() {
        return LiteralIntegerImpl.EMPTY_LITERALINTEGER;
    }

    @Override
    public LiteralIntegerSet emptySet() {
      return new LiteralIntegerSetImpl();
    }

    @Override
    public LiteralIntegerSet emptySet(Comparator<? super LiteralInteger> comp) {
      return new LiteralIntegerSetImpl(comp);
    }

    @Override
    public LiteralIntegerSet value() {
        return this;
    }

    @Override
    public List<LiteralInteger> elements() {
        return Arrays.asList(toArray(new LiteralInteger[0]));
    }

}
